@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckAcls;
 # ABSTRACT: [DEPRECATED] Git::Hooks plugin for branch/tag access control
-$Git::Hooks::CheckAcls::VERSION = '2.9.1';
+$Git::Hooks::CheckAcls::VERSION = '2.9.2';
 use 5.010;
 use utf8;
 use strict;
@@ -56,7 +56,7 @@ sub check_ref {
     } else {
         # This is an U if "merge-base(old, new) == old". Otherwise it's an R.
         $op = eval {
-            chomp(my $merge_base = $git->run('merge-base' => $old_commit, $new_commit));
+            my $merge_base = $git->run('merge-base' => $old_commit, $new_commit);
             ($merge_base eq $old_commit) ? 'U' : 'R';
         } || 'R'; # Probably $old_commit and $new_commit do not have a common ancestor.
     }
@@ -138,7 +138,7 @@ Git::Hooks::CheckAcls - [DEPRECATED] Git::Hooks plugin for branch/tag access con
 
 =head1 VERSION
 
-version 2.9.1
+version 2.9.2
 
 =head1 SYNOPSIS
 
